Knossos
=======

The original idea and prototype were created by Hellzed.
ngld rewrote the manager in Python and extended it.

After installing this package, you can launch Knossos with ``knossos`` or ``python -m knossos``.

Website:
    https://dev.tproxy.de/knossos/

Source Code:
    https://github.com/ngld/knossos

Discussion on HLP:
    http://www.hard-light.net/forums/index.php?topic=86364.new#lastPost
